summaryrefslogtreecommitdiffstats
path: root/kwordquiz/src/kwordquizview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kwordquiz/src/kwordquizview.h')
-rw-r--r--kwordquiz/src/kwordquizview.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/kwordquiz/src/kwordquizview.h b/kwordquiz/src/kwordquizview.h
index 00289925..a15b496e 100644
--- a/kwordquiz/src/kwordquizview.h
+++ b/kwordquiz/src/kwordquizview.h
@@ -15,14 +15,14 @@
* *
***************************************************************************/
-#ifndef KWORDQUIZVIEW_H
-#define KWORDQUIZVIEW_H
+#ifndef KWORDTQUIZVIEW_H
+#define KWORDTQUIZVIEW_H
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
-// include files for Qt
+// include files for TQt
#include <tqtable.h>
#include <kprinter.h>
@@ -41,30 +41,31 @@ class DlgSpecChar;
@author Peter Hedlund
*/
-class KWQTableItem :public QTableItem
+class KWTQTableItem :public TQTableItem
{
public:
- KWQTableItem( TQTable* table, EditType et, const TQString & text );
- virtual int alignment() const;
+ KWTQTableItem( TQTable* table, EditType et, const TQString & text );
+ virtual int tqalignment() const;
};
-class KWordQuizView : public QTable
+class KWordQuizView : public TQTable
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor for the main view */
- KWordQuizView(TQWidget *parent = 0, const char *name=0);
+ KWordQuizView(TQWidget *tqparent = 0, const char *name=0);
/** Destructor for the main view */
~KWordQuizView();
/** returns a pointer to the document connected to the view instance. Mind that this method requires a KWordQuizApp instance as a parent
* widget to get to the window document pointer by calling the KWordQuizApp::getDocument() method.
*
* @see KWordQuizApp#getDocument
*/
KWordQuizDoc *getDocument() const;
- //Reimplemented from QTable
+ //Reimplemented from TQTable
void paintCell ( TQPainter * p, int row, int col, const TQRect & cr, bool selected, const TQColorGroup & cg );
void setFont( const TQFont &);
void setText( int row, int col, const TQString &text );
@@ -89,8 +90,8 @@ class KWordQuizView : public QTable
bool checkSyntax(bool all, bool blanks);
void saveCurrentSelection(bool clear);
protected:
- TQWidget * beginEdit(int row, int col, bool replace);
- void endEdit ( int row, int col, bool accept, bool replace );
+ TQWidget * beginEdit(int row, int col, bool tqreplace);
+ void endEdit ( int row, int col, bool accept, bool tqreplace );
void activateNextCell();
void keyPressEvent( TQKeyEvent* );
bool eventFilter( TQObject*, TQEvent* );
@@ -113,11 +114,11 @@ class KWordQuizView : public QTable
DlgSpecChar* dlgSpecChar;
TQWidget * cellEditor;
/** the list of the undo objects */
- static TQValueList<WQUndo> *m_undoList;
+ static TQValueList<WTQUndo> *m_undoList;
void doNewPage(TQPainter & painter, int res, int type);
void doEndOfPage(TQPainter & painter, int vPos, int pageNum, int res, int type);
bool checkForBlank(const TQString & s, bool blank);
};
-#endif // KWORDQUIZVIEW_H
+#endif // KWORDTQUIZVIEW_H
@@ -41,30 +41,31 @@ class DlgSpecChar;
/** Destructor for the main view */
~KWordQuizView();
- /** returns a pointer to the document connected to the view instance. Mind that this method requires a KWordQuizApp instance as a parent
+ /** returns a pointer to the document connected to the view instance. Mind that this method requires a KWordQuizApp instance as a tqparent
* widget to get to the window document pointer by calling the KWordQuizApp::getDocument() method.
*